<?xml version="1.0" encoding="ISO-8859-1"?>
<!--
Copyright (C) 2010  Paul Wolneykien <manowar@altlinux.org>

This file is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-->
<xsl:stylesheet version="1.0"
	        xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output method="text" encoding="UTF-8" />
<xsl:include href="includes.xslt" />
<xsl:param name="image-prefix" />
<xsl:param name="link-color" select="'0000cc'" />
<xsl:param name="broken-link-color" select="'dd0000'" />
<xsl:param name="link-drawtype" select="2" />
<xsl:param name="node-status-key" select="'node.status'" />
<xsl:param name="node-status-desc" select="'{HOSTNAME} status'" />
<xsl:param name="node-problem" select="'Problems in {HOSTNAME}'" />
<xsl:param name="priority" select="4" />
<xsl:param name="host-status-key" select="'host.status'" />
<xsl:param name="link-triggers" />
<xsl:param name="link-trigger-items" select="'icmpping%'" />
<xsl:template name="add-region" match="/">
  <xsl:param name="node" />
  <xsl:param name="map" />
  <xsl:param name="uplink" />
  <xsl:param name="priority" select="$priority" />
  <xsl:call-template name="add-host" />
  <xsl:choose>
    <xsl:when test="$node">
      <xsl:call-template name="add-node-mirror-item">
	<xsl:with-param name="node" select="." />
	<xsl:with-param name="key" select="$node-status-key" />
	<xsl:with-param name="desc" select="$node-status-desc" />
      </xsl:call-template>
      <xsl:call-template name="append-node-mirror-item">
	<xsl:with-param name="supernode" select="$node" />
	<xsl:with-param name="node" select="." />
	<xsl:with-param name="key" select="$node-status-key" />
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <xsl:call-template name="add-node-item">
	<xsl:with-param name="node" select="." />
	<xsl:with-param name="key" select="$node-status-key" />
	<xsl:with-param name="desc" select="$node-status-desc" />
      </xsl:call-template>
    </xsl:otherwise>
  </xsl:choose>
  <xsl:call-template name="add-trigger">
    <xsl:with-param name="name" select="$node-problem" />
    <xsl:with-param name="key" select="$node-status-key" />
    <xsl:with-param name="function" select="'last'" />
    <xsl:with-param name="priority" select="$priority" />
  </xsl:call-template>
  <xsl:for-each select="map">
    <xsl:call-template name="add-map">
      <xsl:with-param name="prefix" select="$image-prefix" />
    </xsl:call-template>
    <xsl:call-template name="place-host-on-map">
      <xsl:with-param name="map" select="." />
      <xsl:with-param name="host" select=".." />
    </xsl:call-template>
  </xsl:for-each>
  <xsl:if test="$map">
    <xsl:call-template name="place-host-on-map">
      <xsl:with-param name="map" select="$map" />
      <xsl:with-param name="host" select="." />
    </xsl:call-template>
    <xsl:if test="$uplink">
      <xsl:call-template name="link-hosts-on-map">
	<xsl:with-param name="map" select="$map" />
	<xsl:with-param name="host-1" select="$uplink" />
	<xsl:with-param name="host-2" select="." />
      </xsl:call-template>
      <xsl:if test="$link-triggers">
	<xsl:call-template name="add-link-triggers">
	  <xsl:with-param name="map" select="$map" />
	  <xsl:with-param name="host-1" select="$uplink" />
	  <xsl:with-param name="host-2" select="." />
	  <xsl:with-param name="triggers" select="$link-triggers" />
	</xsl:call-template>
      </xsl:if>
      <xsl:if test="$link-trigger-items">
	<xsl:call-template name="add-link-triggers-by-items">
	  <xsl:with-param name="map" select="$map" />
	  <xsl:with-param name="host-1" select="$uplink" />
	  <xsl:with-param name="host-2" select="." />
	  <xsl:with-param name="items" select="$link-trigger-items" />
	</xsl:call-template>
      </xsl:if>
    </xsl:if>
  </xsl:if>
  <xsl:for-each select="supregion">
    <xsl:call-template name="add-node">
      <xsl:with-param name="nodetype" select="0" />
      <xsl:with-param name="masterid" select="0" />
    </xsl:call-template>
  </xsl:for-each>
  <xsl:for-each select="subregions">
    <xsl:call-template name="add-group">
      <xsl:with-param name="name" select="@group" />
    </xsl:call-template>
    <xsl:for-each select="region">
      <xsl:call-template name="add-node">
	<xsl:with-param name="nodetype" select="0" />
	<xsl:with-param name="masterid" select="../../id" />
      </xsl:call-template>
      <xsl:choose>
	<xsl:when test="../../map">
	  <xsl:call-template name="add-region">
	    <xsl:with-param name="node" select="/region" />
	    <xsl:with-param name="map" select="../../map" />
	    <xsl:with-param name="uplink" select="../.." />
	    <xsl:with-param name="priority" select="$priority - 1" />
	  </xsl:call-template>
	</xsl:when>
	<xsl:otherwise>
	  <xsl:call-template name="add-region">
	    <xsl:with-param name="node" select="/region" />
	    <xsl:with-param name="map" select="$map" />
	    <xsl:with-param name="uplink" select="../.." />
	    <xsl:with-param name="priority" select="$priority - 1" />
	  </xsl:call-template>
	</xsl:otherwise>
      </xsl:choose>
    </xsl:for-each>
  </xsl:for-each>
  <xsl:for-each select="hosts">
    <xsl:call-template name="add-group">
      <xsl:with-param name="name" select="@group" />
    </xsl:call-template>
    <xsl:for-each select="host">
      <xsl:call-template name="add-host" />
      <xsl:call-template name="append-host-item">
	<xsl:with-param name="node" select="/region" />
	<xsl:with-param name="key" select="$node-status-key" />
	<xsl:with-param name="host-key" select="$host-status-key" />
      </xsl:call-template>
    </xsl:for-each>
  </xsl:for-each>
</xsl:template>
<xsl:template match="/">
  <xsl:for-each select="region">
    <xsl:call-template name="add-region" />
  </xsl:for-each>
</xsl:template>
</xsl:stylesheet>
